@@ -1,5 +1,5 @@
-IDFcurve <- function (rain, g, s, tc, stvalue1 = 1, stvalue2 = fre, fre, Tr = 200, 
-                      MP = F, Trplot = F) 
+IDFcurve <- function (rain, g, s, tc, stvalue1 = 1, stvalue2 = fre, fre, Tr = 200,
+                      MP = F, Trplot = F)
 { options(warn = -1)
   rain <- as.matrix(rain)
   Y = (nrow(rain)*fre)/(365*24)
@@ -15,13 +15,13 @@ IDFcurve <- function (rain, g, s, tc, stvalue1 = 1, stvalue2 = fre, fre, Tr = 20
   Tr <- Tr*ne
   vb1 <- vb(nr - 1)
   ris <- nlm(f3, c(vb1, stvalue1), x3 = Ev2, fre = fre, iterlim = 1000)
-  if (MP) 
-    ris <- nlm(f2, c(ris$estimate, stvalue2), x3 = Ev2, fre = fre, 
+  if (MP)
+    ris <- nlm(f2, c(ris$estimate, stvalue2), x3 = Ev2, fre = fre,
               iterlim = 1000)
   mu <- mean(ris$estimate[1:nr]) - 0.45006 * sd(ris$estimate[1:nr])
   sigma <- sd(ris$estimate[1:nr])/1.2825
-  a <- qGumbel(1 - 1/Tr, sigma = sigma, mu = mu)
-  pr <- pGumbel(ris$estimate[1:nr], sigma = sigma, mu = mu)
+  a <- qgumbel(1 - 1/Tr, sigma = sigma, mu = mu)
+  pr <- pgumbel(ris$estimate[1:nr], sigma = sigma, mu = mu)
   tr <- 1/(1-pr)
   tr <- tr/ne
   if (MP) {
@@ -39,12 +39,12 @@ IDFcurve <- function (rain, g, s, tc, stvalue1 = 1, stvalue2 = fre, fre, Tr = 20
   h <- a * tc/(b + tc)^m
   i <- a/(b + tc)^m
   out <- list(par = c(a, m, h, i, min), Curve = iH)
-    ts.plot(ts(t(Ev3[1:10, ]), start = fre, end = fre * g, frequency = 1/fre), 
+    ts.plot(ts(t(Ev3[1:10, ]), start = fre, end = fre * g, frequency = 1/fre),
           type = "p",  ylab="I[mm/h]", xlab="t[h]")
   for (w in 1:10) lines(x = seq(fre, fre * g, fre), y = iH[w, ], col = "red")
     if (Trplot)
   legend("topright", paste("Tr.plot =", round(tr[1:10],2), "\n"), text.col = "red")
-    if (MP) 
+    if (MP)
     cat("m = ", m, "\n")
   else cat("n = ", 1 - m, "\n")
   cat("b = ", b, "\n")
