@@ -19,13 +19,13 @@ structure(function (x, fre)
 "\t\t}", "\t}", "\tEt * 10", "}"))
 #' @keywords internal
 PW <-
-function (x, frvol, R, type = "Mi")
+function (x, frvol, R)
 {
   fre <- 12
   R1 <- frvol * R * 10
   cat("Maximum water reserve <- ", R1, "\n")
   n <- length(x)
-  out1 <- MSeason(FIdrico2(x, fre, R, R1, type),
+  out1 <- MSeason(FIdrico2(x, fre, R, R1),
     fre)
     out <- out1
 }
@@ -89,19 +89,15 @@ structure(function (ls, fre, o)
 ))
 #' @keywords internal
 FIdrico2 <-
-function (y, fre, R, R1, type = "Mi")
+function (y, fre, R, R1)
 { erb=F
   pe <- vector()
   Fi <- vector()
   fi <- vector()
   ET <- Thornthwaite(y[, 2], fre)
   pe <- Pe1(y[, 1], fre)
-  if (erb)
-    df <- Df(y[, 3], R, type)
   for (k in 1:nrow(y)) {
-    if (erb)
-      fi[k] <- (1 - df[k]) * ET[k] - pe[k]
-    else fi[k] <- ET[k] - pe[k]
+  fi[k] <- ET[k] - pe[k]
   }
   if (erb == F) {
     for (j in 1:(nrow(y) - 1)) {
@@ -134,146 +130,6 @@ function (y, fre, R, R1, type = "Mi")
   Fi
 }
 #' @keywords internal
-Df <-
-structure(function (x, R, type = "Mi")
-{
-    if (type == "Mi") {
-        n <- length(x)
-        Y <- vector()
-        for (i in 1:n) {
-            if ((R == 40) && (x[i] > 50))
-                Y[i] <- -47.823309999999999 + 7.2017680000000004 *
-                  x[i] - 0.105087 * x[i]^2 + 0.00040200000000000001 *
-                  x[i]^3
-            if ((R == 40) && (x[i] <= 50))
-                Y[i] <- 100
-            if ((R == 40) && (x[i] > 115))
-                Y[i] <- 0
-            if ((R == 60) && (x[i] > 60))
-                Y[i] <- 16.139963999999999 + 3.0600170000000002 *
-                  x[i] - 0.032861000000000001 * x[i]^2 + 8.5000000000000006e-05 *
-                  x[i]^3
-            if ((R == 60) && (x[i] <= 60))
-                Y[i] <- 100
-            if ((R == 60) && (x[i] > 175))
-                Y[i] <- 0
-            if ((R == 80) && (x[i] > 80))
-                Y[i] <- -46.986013999999997 + 3.7565460000000002 *
-                  x[i] - 0.028961000000000001 * x[i]^2 + 5.8999999999999998e-05 *
-                  x[i]^3
-            if ((R == 80) && (x[i] <= 80))
-                Y[i] <- 100
-            if ((R == 80) && (x[i] > 230))
-                Y[i] <- 0
-            if (Y[i] < 0)
-                Y[i] <- 0
-        }
-    }
-    if (type == "Sb") {
-        n <- length(x)
-        Y <- vector()
-        for (i in 1:n) {
-            if ((R == 40) && (x[i] > 50))
-                Y[i] <- -74.014476000000002 + 8.4906310000000005 *
-                  x[i] - 0.124338 * x[i]^2 + 0.000484 * x[i]^3
-            if ((R == 40) && (x[i] <= 50))
-                Y[i] <- 100
-            if ((R == 40) && (x[i] > 105))
-                Y[i] <- 0
-            if ((R == 60) && (x[i] > 60))
-                Y[i] <- 2.5763669999999999 + 3.5583939999999998 *
-                  x[i] - 0.038304999999999999 * x[i]^2 + 0.000101 *
-                  x[i]^3
-            if ((R == 60) && (x[i] <= 60))
-                Y[i] <- 100
-            if ((R == 60) && (x[i] > 170))
-                Y[i] <- 0
-            if ((R == 80) && (x[i] > 80))
-                Y[i] <- -76.410022999999995 + 4.4588479999999997 *
-                  x[i] - 0.034051999999999999 * x[i]^2 + 6.9999999999999994e-05 *
-                  x[i]^3
-            if ((R == 80) && (x[i] <= 80))
-                Y[i] <- 100
-            if ((R == 80) && (x[i] > 230))
-                Y[i] <- 0
-            if (Y[i] < 0)
-                Y[i] <- 0
-        }
-    }
-    if (type == "Ar") {
-        n <- length(x)
-        Y <- vector()
-        for (i in 1:n) {
-            if ((R == 40) && (x[i] > 50))
-                Y[i] <- 21.908625000000001 + 4.8351009999999999 *
-                  x[i] - 0.082493999999999998 * x[i]^2 + 0.00033700000000000001 *
-                  x[i]^3
-            if ((R == 40) && (x[i] <= 50))
-                Y[i] <- 100
-            if ((R == 40) && (x[i] > 110))
-                Y[i] <- 0
-            if ((R == 60) && (x[i] > 60))
-                Y[i] <- 83.104050999999998 + 1.3151740000000001 *
-                  x[i] - 0.020656999999999998 * x[i]^2 + 6.0000000000000002e-05 *
-                  x[i]^3
-            if ((R == 60) && (x[i] <= 60))
-                Y[i] <- 100
-            if ((R == 60) && (x[i] > 175))
-                Y[i] <- 0
-            if ((R == 80) && (x[i] > 80))
-                Y[i] <- 106.304895 + 0.60338999999999998 * x[i] -
-                  0.010817 * x[i]^2 + 2.6999999999999999e-05 *
-                  x[i]^3
-            if ((R == 80) && (x[i] <= 80))
-                Y[i] <- 100
-            if ((R == 80) && (x[i] > 220))
-                Y[i] <- 0
-            if (Y[i] < 0)
-                Y[i] <- 0
-        }
-    }
-    for (j in 1:n) if (Y[j] > 100)
-        Y[j] = 100
-    Y/100
-}, source = c("function(x, R, type = \"Mi\")", "{", "\tif(type == \"Mi\") {",
-"\t\tn <- length(x)", "\t\tY <- vector()", "\t\tfor(i in 1:n) {",
-"\t\t\tif((R == 40) && (x[i] > 50))", "\t\t\t\tY[i] <- -47.82331 + 7.201768 * x[i] - 0.105087 * ",
-"\t\t\t\t  x[i]^2 + 0.000402 * x[i]^3", "\t\t\tif((R == 40) && (x[i] <= 50))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 40) && (x[i] > 115))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif((R == 60) && (x[i] > 60))", "\t\t\t\tY[i] <- 16.139964 + 3.060017 * x[i] - 0.032861 * ",
-"\t\t\t\t  x[i]^2 + 8.5e-005 * x[i]^3", "\t\t\tif((R == 60) && (x[i] <= 60))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 60) && (x[i] > 175))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif((R == 80) && (x[i] > 80))", "\t\t\t\tY[i] <- -46.986014 + 3.756546 * x[i] - 0.028961 *",
-"\t\t\t\t  x[i]^2 + 5.9e-005 * x[i]^3", "\t\t\tif((R == 80) && (x[i] <= 80))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 80) && (x[i] > 230))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif(Y[i] < 0)", "\t\t\t\tY[i] <- 0",
-"\t\t}}", "\t\t", "\t", "\tif(type == \"Sb\") {", "\t\tn <- length(x)",
-"\t\tY <- vector()", "\t\tfor(i in 1:n) {", "\t\t\tif((R == 40) && (x[i] > 50))",
-"\t\t\t\tY[i] <- -74.014476 + 8.490631 * x[i] - 0.124338 *",
-"\t\t\t\t  x[i]^2 + 0.000484 * x[i]^3", "\t\t\tif((R == 40) && (x[i] <= 50))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 40) && (x[i] > 105))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif((R == 60) && (x[i] > 60))", "\t\t\t\tY[i] <- 2.576367 + 3.558394 * x[i] - 0.038305 * ",
-"\t\t\t\t  x[i]^2 + 0.000101 * x[i]^3", "\t\t\tif((R == 60) && (x[i] <= 60))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 60) && (x[i] > 170))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif((R == 80) && (x[i] > 80))", "\t\t\t\tY[i] <- -76.410023 + 4.458848 * x[i] - 0.034052 *",
-"\t\t\t\t  x[i]^2 + 7e-005 * x[i]^3", "\t\t\tif((R == 80) && (x[i] <= 80))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 80) && (x[i] > 230))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif(Y[i] < 0)", "\t\t\t\tY[i] <- 0",
-"\t\t}}", "\t\t", "\t", "\tif(type == \"Ar\") {", "\t\tn <- length(x)",
-"\t\tY <- vector()", "\t\tfor(i in 1:n) {", "\t\t\tif((R == 40) && (x[i] > 50))",
-"\t\t\t\tY[i] <- 21.908625 + 4.835101 * x[i] - 0.082494 * ",
-"\t\t\t\t  x[i]^2 + 0.000337 * x[i]^3", "\t\t\tif((R == 40) && (x[i] <= 50))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 40) && (x[i] > 110))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif((R == 60) && (x[i] > 60))", "\t\t\t\tY[i] <- 83.104051 + 1.315174 * x[i] - 0.020657 * ",
-"\t\t\t\t  x[i]^2 + 6e-005 * x[i]^3", "\t\t\tif((R == 60) && (x[i] <= 60))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 60) && (x[i] > 175))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif((R == 80) && (x[i] > 80))", "\t\t\t\tY[i] <- 106.304895 + 0.60339 * x[i] - 0.010817 * ",
-"\t\t\t\t  x[i]^2 + 2.7e-005 * x[i]^3", "\t\t\tif((R == 80) && (x[i] <= 80))",
-"\t\t\t\tY[i] <- 100", "\t\t\tif((R == 80) && (x[i] > 220))",
-"\t\t\t\tY[i] <- 0", "\t\t\tif(Y[i] < 0)", "\t\t\t\tY[i] <- 0",
-"\t\t}}", "for (j in 1:n) ", "if (Y[j]>100) Y[j]=100\t", "\t\tY/100",
-"\t", "}"))
-#' @keywords internal
 contaleva2 <-
 structure(function (x, a, ser)
 {
